==> docx4j-openxml-objects-8.1.1-sources.jar: org/docx4j/math/CTNaryPr.java <==
/*
 *  Copyright 2009-2012, Plutext Pty Ltd.
 *   
 *  This file is part of pptx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.docx4j.math;

import javax.xml.bind.Unmarshaller;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_NaryPr complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_NaryPr">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="chr" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_Char" minOccurs="0"/>
 *         &lt;element name="limLoc" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_LimLoc" minOccurs="0"/>
 *         &lt;element name="grow" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_OnOff" minOccurs="0"/>
 *         &lt;element name="subHide" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_OnOff" minOccurs="0"/>
 *         &lt;element name="supHide" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_OnOff" minOccurs="0"/>
 *         &lt;element name="ctrlPr" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_CtrlPr" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_NaryPr", propOrder = {
    "chr",
    "limLoc",
    "grow",
    "subHide",
    "supHide",
    "ctrlPr"
})
public class CTNaryPr
    implements Child
{

    protected CTChar chr;
    protected CTLimLoc limLoc;
    protected CTOnOff grow;
    protected CTOnOff subHide;
    protected CTOnOff supHide;
    protected CTCtrlPr ctrlPr;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the chr property.
     * 
     * @return
     *     possible object is
     *     {@link CTChar }
     *     
     */
    public CTChar getChr() {
        return chr;
    }

    /**
     * Sets the value of the chr property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTChar }
     *     
     */
    public void setChr(CTChar value) {
        this.chr = value;
    }

    /**
     * Gets the value of the limLoc property.
     * 
     * @return
     *     possible object is
     *     {@link CTLimLoc }
     *     
     */
    public CTLimLoc getLimLoc() {
        return limLoc;
    }

    /**
     * Sets the value of the limLoc property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTLimLoc }
     *     
     */
    public void setLimLoc(CTLimLoc value) {
        this.limLoc = value;
    }

    /**
     * Gets the value of the grow property.
     * 
     * @return
     *     possible object is
     *     {@link CTOnOff }
     *     
     */
    public CTOnOff getGrow() {
        return grow;
    }

    /**
     * Sets the value of the grow property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTOnOff }
     *     
     */
    public void setGrow(CTOnOff value) {
        this.grow = value;
    }

    /**
     * Gets the value of the subHide property.
     * 
     * @return
     *     possible object is
     *     {@link CTOnOff }
     *     
     */
    public CTOnOff getSubHide() {
        return subHide;
    }

    /**
     * Sets the value of the subHide property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTOnOff }
     *     
     */
    public void setSubHide(CTOnOff value) {
        this.subHide = value;
    }

    /**
     * Gets the value of the supHide property.
     * 
     * @return
     *     possible object is
     *     {@link CTOnOff }
     *     
     */
    public CTOnOff getSupHide() {
        return supHide;
    }

    /**
     * Sets the value of the supHide property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTOnOff }
     *     
     */
    public void setSupHide(CTOnOff value) {
        this.supHide = value;
    }

    /**
     * Gets the value of the ctrlPr property.
     * 
     * @return
     *     possible object is
     *     {@link CTCtrlPr }
     *     
     */
    public CTCtrlPr getCtrlPr() {
        return ctrlPr;
    }

    /**
     * Sets the value of the ctrlPr property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTCtrlPr }
     *     
     */
    public void setCtrlPr(CTCtrlPr value) {
        this.ctrlPr = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}

==> docx4j-openxml-objects-11.5.0-sources.jar: org/docx4j/math/CTNaryPr.java <==
/*
 *  Copyright 2009-2012, Plutext Pty Ltd.
 *   
 *  This file is part of pptx4j, a component of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */
package org.docx4j.math;

import jakarta.xml.bind.Unmarshaller;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlTransient;
import jakarta.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.ppp.Child;


/**
 * <p>Java class for CT_NaryPr complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CT_NaryPr">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="chr" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_Char" minOccurs="0"/>
 *         &lt;element name="limLoc" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_LimLoc" minOccurs="0"/>
 *         &lt;element name="grow" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_OnOff" minOccurs="0"/>
 *         &lt;element name="subHide" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_OnOff" minOccurs="0"/>
 *         &lt;element name="supHide" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_OnOff" minOccurs="0"/>
 *         &lt;element name="ctrlPr" type="{http://schemas.openxmlformats.org/officeDocument/2006/math}CT_CtrlPr" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CT_NaryPr", propOrder = {
    "chr",
    "limLoc",
    "grow",
    "subHide",
    "supHide",
    "ctrlPr"
})
public class CTNaryPr
    implements Child
{

    protected CTChar chr;
    protected CTLimLoc limLoc;
    protected CTOnOff grow;
    protected CTOnOff subHide;
    protected CTOnOff supHide;
    protected CTCtrlPr ctrlPr;
    @XmlTransient
    private Object parent;

    /**
     * Gets the value of the chr property.
     * 
     * @return
     *     possible object is
     *     {@link CTChar }
     *     
     */
    public CTChar getChr() {
        return chr;
    }

    /**
     * Sets the value of the chr property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTChar }
     *     
     */
    public void setChr(CTChar value) {
        this.chr = value;
    }

    /**
     * Gets the value of the limLoc property.
     * 
     * @return
     *     possible object is
     *     {@link CTLimLoc }
     *     
     */
    public CTLimLoc getLimLoc() {
        return limLoc;
    }

    /**
     * Sets the value of the limLoc property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTLimLoc }
     *     
     */
    public void setLimLoc(CTLimLoc value) {
        this.limLoc = value;
    }

    /**
     * Gets the value of the grow property.
     * 
     * @return
     *     possible object is
     *     {@link CTOnOff }
     *     
     */
    public CTOnOff getGrow() {
        return grow;
    }

    /**
     * Sets the value of the grow property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTOnOff }
     *     
     */
    public void setGrow(CTOnOff value) {
        this.grow = value;
    }

    /**
     * Gets the value of the subHide property.
     * 
     * @return
     *     possible object is
     *     {@link CTOnOff }
     *     
     */
    public CTOnOff getSubHide() {
        return subHide;
    }

    /**
     * Sets the value of the subHide property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTOnOff }
     *     
     */
    public void setSubHide(CTOnOff value) {
        this.subHide = value;
    }

    /**
     * Gets the value of the supHide property.
     * 
     * @return
     *     possible object is
     *     {@link CTOnOff }
     *     
     */
    public CTOnOff getSupHide() {
        return supHide;
    }

    /**
     * Sets the value of the supHide property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTOnOff }
     *     
     */
    public void setSupHide(CTOnOff value) {
        this.supHide = value;
    }

    /**
     * Gets the value of the ctrlPr property.
     * 
     * @return
     *     possible object is
     *     {@link CTCtrlPr }
     *     
     */
    public CTCtrlPr getCtrlPr() {
        return ctrlPr;
    }

    /**
     * Sets the value of the ctrlPr property.
     * 
     * @param value
     *     allowed object is
     *     {@link CTCtrlPr }
     *     
     */
    public void setCtrlPr(CTCtrlPr value) {
        this.ctrlPr = value;
    }

    /**
     * Gets the parent object in the object tree representing the unmarshalled xml document.
     * 
     * @return
     *     The parent object.
     */
    public Object getParent() {
        return this.parent;
    }

    public void setParent(Object parent) {
        this.parent = parent;
    }

    /**
     * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
     * 
     * @param parent
     *     The parent object in the object tree.
     * @param unmarshaller
     *     The unmarshaller that generated the instance.
     */
    public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
        setParent(parent);
    }

}
